[![License](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0.html)
![First Principles Software](https://img.shields.io/badge/Powered_by-First_Principles_Software-blue)

> [!NOTE]
> This project is still a scaffold. Check back soon for the next release.

## py-scheduling-library

A scheduling library for Python.

### Features:

- ...

### Python Compatibility

This library is compatible and tested with the following Python versions:

- Python 3.7
- Python 3.8
- Python 3.9
- Python 3.10
- Python 3.11
- Python 3.12

[![Push on master](https://github.com/runemalm/py-scheduling-library/actions/workflows/master.yml/badge.svg?branch=master)](https://github.com/runemalm/py-scheduling-library/actions/workflows/master.yml)
  
### Installation:
  
```bash
$ pip install py-scheduling-library
```
  
### Example - xxx

```python
# ...
```

### Documentation:
  
You can find the latest documentation at [readthedocs](https://py-scheduling-library.readthedocs.io/en/latest/).

### Contribution:
  
If you want to contribute to the code base, create a pull request on the develop branch.

We follow the [git flow](https://nvie.com/posts/a-successful-git-branching-model/) branching model.
  
### Release Notes

#### [1.0.0-alpha.1](https://github.com/runemalm/py-scheduling-library/releases/tag/v1.0.0-alpha.1) (2024-03-20)

This is a scaffold release. Check back soon for the next release.

- **Initial Commit:** Created the project.
- **PyPi:** Released scaffold package on PyPi.
- **Documentation:** Added scaffold docs to readthedocs.
- **License:** Released under the GPL 3 license.
